#### Online Appendix 6.1 ####

# load packages
  library(nlme)
  library(AICcmodavg)
  library(emdbook)

# load data
  growth = read.csv(file.choose())

# subset data by sex 
  growth$PRECIP <- scale(growth$PRECIP)
  growth_mal = subset(growth, growth$SEX == "m")
  growth_fem = subset(growth, growth$SEX == "f")

# Create parm_diff: a logistic function for growth
  parm_diff = function(AGE,COND, Asym, xmid, K, Kdiff, middiff, Adiff){
                    (Asym + Adiff*COND)/(1 + exp(((xmid+middiff*COND) - AGE)*(K+Kdiff*COND)))
                }

# p.diff_Deriv derives the logistic function above (parm_diff) 
  p.diff_Deriv = deriv(body(parm_diff)[[2]], namevec = c("Asym", "xmid", "K", "Kdiff", "middiff", "Adiff"), function.arg= parm_diff)
	
# start values for males (PEFA)
  startmal = c(Asym = 700, xmid = 3, K = .05, Kdiff=0, middiff=0, Adiff = 0) # Start values for males (PEFA)

# start values for females (PEFA)
  startfem = c(Asym = 700, xmid = 3, K = .05, Kdiff=0, middiff=0, Adiff = 0) # Start values for females (PEFA)

## MALES 

# 1. Model with NEST-level random effect on the ASYMPTOTIC MASS
	r.n_f.a._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.a._males)

# 2. Model with NESTLING-level random effect on the ASYMPTOTIC MASS 
	r.ng_f.a._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym ~ 1 | ID, data = growth_mal, start = startmal)
	summary(r.ng_f.a._males)

# 3. Model with NEST random effect on the INFLECTION 
	r.n_f.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = xmid ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.i._males)

# 4. Model with NESTLING-level random effect on the INFLECTION 
	r.ng_f.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = xmid ~ 1 | ID, data = growth_mal, start = startmal)
	summary(r.ng_f.i._males)

# 5. Model with NEST random effect on the growth CONSTANT
	r.n_f.k._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = K ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.k._males)

# 6. Model with nestling-level random effect on the growth constant
	r.ng_f.k._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = K ~ 1 | ID, data = growth_mal, start = startmal)
	summary(r.ng_f.k._males)

# 7. Model with nest level random effect on asymptote and inflection
	r.n_f.a.i_males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym + xmid ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.a.i_males) # This model doesn't converge, and is deemed to be over-parameterized

# 8. Model with nestling-level random effect on the asymptotic and inflection
	r.ng_f.a.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym + xmid ~ 1 | ID, data = growth_mal, start = startmal)
	summary(r.ng_f.a.i._males)
     
# 9. Model with Nest level random effect on all three parameters
	r.n_f.a.k.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym + K + xmid ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.a.k.i._males)

## Double random effect structure 
	
# 10. model with nest/nestling level random effects on asymptote and inflection 
	r.n.ng_f.a.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym + xmid ~ 1 | ID/NEST, data = growth_mal, start = startmal)
	summary(r.n.ng_f.a.i._males)

# 11. model with nest/nestling level random effects on inflection
	r.n.ng_f.i._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = xmid ~ 1 | NEST/ID, data = growth_mal, start = startmal)
	summary(r.n.ng_f.i._males)

# 12. model with nest/nestling level random effects on asymptote
	r.n.ng_f.a._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym ~ 1 | NEST/ID, data = growth_mal, start = startmal)
	summary(r.n.ng_f.a._males)

# 13. model with nest/nestling level random effects on growth constant
	r.n.ng_f.k._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = K ~ 1 | NEST/ID, data = growth_mal, start = startmal)
	summary(r.n.ng_f.k._males)

# 14. model with no random effects ####
	norandom_males = gnls(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), data = growth_mal, start = startmal, control=list(tolerance=50))
	summary(norandom_males)


## plot growth curve and error using the Delta-Var method

# model
	r.n_f.a._males = nlme(WEIGHT ~ p.diff_Deriv
		(AGE, COND, Asym, xmid, K, Kdiff, middiff, Adiff), fixed = Asym + xmid + K + Kdiff + middiff + Adiff ~ 1, random = Asym ~ 1 | NEST, data = growth_mal, start = startmal)
	summary(r.n_f.a._males)

# manually save the parameter estimates to objects (values obtained from model summary)
	Asym_est    =  1142.557
	xmid_est    =  13.3460
	K_est       =  0.2242
	Kdiff_est   =  0.0109
	middiff_est = -0.1663
	Adiff_est   =  71.7208

# create a matrix of the model's variance covariance
	sigma = matrix(vcov(r.n_f.a._males),nrow=6, ncol=6)

# vector of ages spanning 0 to 35 days
	age_vec = seq(0, 35, by = 1)

# growth in wet conditions
	Mass_wet = Asym_est/(1 + exp((xmid_est - age_vec)* K_est))

# growth in dry conditions
	Mass_dry = (Asym_est + Adiff_est)/(1 + exp(((xmid_est+middiff_est) - age_vec)*(K_est+Kdiff_est)))

# treatment 
	wet = 0
	dry = 1

# standard error for growth in wet conditions
	se_wet.mass = sqrt(deltavar((Asym_est + Adiff_est*wet)/(1 + exp(((xmid_est+middiff_est*wet) - age_vec)*(K_est+Kdiff_est*wet))), meanval = c(Asym_est = Asym_est, xmid_est = xmid_est, K_est = K_est,  Kdiff_est = Kdiff_est, middiff_est = middiff_est, Adiff_est = Adiff_est), Sigma=sigma ))

# calculate upper and lower confidence intervals from the SE for growth in wet conditions
	wet_ucl = Mass_wet + 1.96*se_wet.mass
	wet_lcl = Mass_wet - 1.96*se_wet.mass

# standard error for growth in dry conditions
	se_dry.mass =sqrt(deltavar((Asym_est + Adiff_est*dry)/(1 + exp(((xmid_est+middiff_est*dry) - age_vec)*(K_est+Kdiff_est*dry))), meanval = c(Asym_est = Asym_est, xmid_est = xmid_est, K_est = K_est,  Kdiff_est = Kdiff_est, middiff_est = middiff_est, Adiff_est = Adiff_est), Sigma=sigma ))

# calculate upper and lower confidence intervals from the SE for growth in dry conditions
	dry_ucl = Mass_dry + 1.96*se_dry.mass
	dry_lcl = Mass_dry - 1.96*se_dry.mass


# plot the curves
	graphics.off()
	windows(4.5,4.5)
	par(mgp=c(1.5,0.5,0))
	plot  (age_vec, Mass_wet, type = "n", cex.lab=0.6, cex.axis=0.75, xlab = "Age (days)", tck=0.01, font.lab=2, ylab = 'Weight (g)', las = 1, ylim = c(0,1500), xaxs = "i", yaxs = "i", bty = "l", cex.lab = 1,axes=T)
	lines(age_vec, Mass_wet, lty = 1, lwd = 1, col = rgb(0.1,0.1,0.8,1))
	lines(age_vec, wet_ucl,  lty = 2, lwd = 1, col = rgb(0.1,0.1,0.8,0.5))
	lines(age_vec, wet_lcl,  lty = 2, lwd = 1, col = rgb(0.1,0.1,0.8,0.5))
	lines(age_vec, Mass_dry, lty = 1, lwd = 1, col = rgb(0,0,0,1))
	lines(age_vec, dry_ucl,  lty = 2, lwd = 1, col = rgb(0,0,0,0.5))
	lines(age_vec, dry_lcl,  lty = 2, lwd = 1, col = rgb(0,0,0,0.5))
	points(growth_mal$WEIGHT[growth_mal$COND==0]~growth_mal$AGE[growth_mal$COND==0], pch=19,col = rgb(0.1,0.1,0.8,0.2),cex=0.2)
	points(growth_mal$WEIGHT[growth_mal$COND==1]~growth_mal$AGE[growth_mal$COND==1], pch=19,col = rgb(0,0,0,0.2), cex=0.2)
	legend(25,600, bty = "n", legend = "Dry", text.col = rgb(0,0,0,1),cex=0.75)
	  legend(28,525, bty="n", legend = "a = 1,214",cex = 0.5)
	  legend(28,475, bty = "n",legend = "i  = 13.46", cex=0.5)
	  legend(28,425, bty = "n",legend = "k = 0.23", cex=0.5)
	legend(25,350, bty = "n", legend = "Wet", text.col = rgb(0.1,0.1,0.8,1),cex=0.75)
	  legend(28,275, bty = "n", legend = "a = 1,142", text.col = rgb(0.1,0.1,0.8,1),cex=0.5)
  	legend(28,225, bty = "n", legend = "i  = 13.35", text.col = rgb(0.1,0.1,0.8,1),cex=0.5)
  	legend(28,175, bty = "n", legend = "k = 0.22", text.col = rgb(0.1,0.1,0.8,1),cex=0.5)

